# Stripe Subscription Full App

A full-stack application implementing Stripe subscriptions with a React frontend and Node.js backend.

## Prerequisites

- Node.js (v14 or higher)
- npm or yarn
- Stripe account
- Git

## Setup Instructions

### 1. Clone the Repository
```bash
git clone <repository-url>
cd stripe-subscription-full-app
```

### 2. Environment Setup

#### Backend (.env)
Create a `.env` file in the server directory with the following variables:
```
STRIPE_SECRET_KEY=your_stripe_secret_key
STRIPE_WEBHOOK_SECRET=your_stripe_webhook_secret
PORT=5000
```

#### Frontend (.env)
Create a `.env` file in the client directory with:
```
VITE_STRIPE_PUBLISHABLE_KEY=your_stripe_publishable_key
```

### 3. Backend Setup

1. Navigate to the server directory:
```bash
cd server
```

2. Install dependencies:
```bash
npm install
```

3. Install required packages:
```bash
npm install express cors dotenv stripe body-parser
```

4. Start the server:
```bash
npm start
```

The server will run on http://localhost:5000

### 4. Frontend Setup

1. Navigate to the client directory:
```bash
cd client
```

2. Install dependencies:
```bash
npm install
```

3. Install required packages:
```bash
npm install @stripe/stripe-js axios react-router-dom
```

4. Start the development server:
```bash
npm run dev
```

The frontend will run on http://localhost:5173

### 5. Stripe Configuration

1. Create a Stripe account at https://stripe.com
2. Get your API keys from the Stripe Dashboard
3. Create a product and price in the Stripe Dashboard
4. Set up a webhook endpoint in the Stripe Dashboard:
   - URL: http://localhost:5000/webhook
   - Events to listen for:
     - checkout.session.completed
     - invoice.payment_failed

### 6. Testing the Application

1. Ensure both frontend and backend servers are running
2. Navigate to http://localhost:5173
3. Select a subscription plan
4. Complete the checkout process using Stripe test card:
   - Card number: 4242 4242 4242 4242
   - Expiry: Any future date
   - CVC: Any 3 digits
   - ZIP: Any 5 digits

## Project Structure

```
stripe-subscription-full-app/
├── client/                 # Frontend React application
│   ├── src/               # Source files
│   ├── public/            # Static files
│   └── package.json       # Frontend dependencies
└── server/                # Backend Node.js application
    ├── index.js          # Main server file
    └── package.json      # Backend dependencies
```

## Features

- Stripe subscription integration
- Secure payment processing
- Webhook handling for subscription events
- Responsive frontend design
- Custom checkout form
- Address collection
- Subscription management

## Security Notes

- Never commit your `.env` files
- Keep your Stripe secret keys secure
- Use environment variables for sensitive data
- Implement proper error handling
- Use HTTPS in production

## Troubleshooting

1. If the server fails to start:
   - Check if the port is already in use
   - Verify environment variables are set correctly
   - Ensure all dependencies are installed

2. If Stripe integration fails:
   - Verify API keys are correct
   - Check webhook configuration
   - Ensure proper CORS settings

## Support

For issues and questions, please open an issue in the repository.

## License

MIT License 