import React from 'react';


const Plans = () => {

  const plans = [
  {
    name: 'Basic',
    price: '₹1,000',
    features: [
      '1 project',
      'Basic support',
      '24/7 access',
      'Basic analytics'
    ],
    priceId: 'price_1RUP0USF61vTyQk0InchPf2z'
  },
  {
    name: 'Premium',
    price: '₹2,000',
    features: [
      'Unlimited projects',
      'Premium support',
      '24/7 priority access',
      'Advanced analytics',
      'Custom integrations'
    ],
    priceId: 'price_1RSAIeSF61vTyQk0Ny0Czz08'
  }
];


  const handleSubscribe = async (priceId) => {
    try {
      const res = await fetch("http://localhost:5000/stripe-checkout-session", {
        method: "POST",
        headers: {
          "Content-Type": "application/json"
        },
        body: JSON.stringify({ priceId })
      });
      const data = await res.json();
      if (data?.url) {
        window.location.href = data.url;
      } else {
        alert("Failed to redirect. Please try again.");
      }
    } catch (error) {
      console.error("Subscription error", error);
      alert("An error occurred during checkout.");
    }
  };

  return (
    <div className="min-h-screen bg-gradient-to-br from-blue-50 to-indigo-100 py-12 px-4 sm:px-6 lg:px-8">
      <div className="max-w-7xl mx-auto">
        <div className="text-center mb-12">
          <h2 className="text-4xl font-extrabold text-gray-900 sm:text-5xl sm:tracking-tight lg:text-6xl">
            Choose Your Plan
          </h2>
          <p className="mt-5 max-w-xl mx-auto text-xl text-gray-500">
            Select the perfect plan for your needs
          </p>
        </div>

        <div className="mt-12 space-y-4 sm:mt-16 sm:space-y-0 sm:grid sm:grid-cols-2 sm:gap-6 lg:max-w-4xl lg:mx-auto">


          {plans.map((plan) => (
            <div
              key={plan.id}
              className="bg-white rounded-2xl shadow-xl overflow-hidden transform transition-all hover:scale-105"
            >
              <div className="px-6 py-8">
                <h3 className="text-2xl font-semibold text-gray-900">{plan.name}</h3>
                <p className="mt-4">
                  <span className="text-4xl font-extrabold text-gray-900">{plan.price}</span>
                  <span className="text-base font-medium text-gray-500">/month</span>
                </p>
                <ul className="mt-6 space-y-4">
                  {plan.features.map((feature) => (
                    <li key={feature} className="flex items-start">
                      <div className="flex-shrink-0">
                        <svg
                          className="h-6 w-6 text-green-500"
                          fill="none"
                          stroke="currentColor"
                          viewBox="0 0 24 24"
                        >
                          <path
                            strokeLinecap="round"
                            strokeLinejoin="round"
                            strokeWidth="2"
                            d="M5 13l4 4L19 7"
                          />
                        </svg>
                      </div>
                      <p className="ml-3 text-base text-gray-700">{feature}</p>
                    </li>
                  ))}
                </ul>
                <button
                  onClick={() => handleSubscribe(plan.priceId)}
                  className="mt-8 block w-full bg-indigo-600 text-white rounded-lg px-6 py-3 text-center font-semibold hover:bg-indigo-700 transition-colors duration-300 shadow-md hover:shadow-lg"
                >
                  Subscribe Now
                </button>
              </div>
            </div>
          ))}
        </div>
      </div>
    </div>
  );
};

export default Plans; 